% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/render_report.R, R/render_reports.R
\name{render_report}
\alias{render_report}
\alias{render_reports}
\title{Render fairify reports}
\usage{
render_report(
  input,
  output_dir,
  output_format = Sys.getenv("BOOKDOWN_FORMAT", "bookdown::gitbook"),
  clean_cache = FALSE,
  ...
)

render_reports(
  reports_dir = file.path(pkgload::pkg_path(), "reports"),
  reports = list.dirs(reports_dir, full.names = FALSE, recursive = FALSE),
  publish_dir = file.path(dirname(reports_dir), "public/reports"),
  ...
)
}
\arguments{
\item{input}{A directory, an input filename or multiple filenames. For a
directory, \file{index.Rmd} will be used if it exists in this (book)
project directory. For filenames, if \code{preview = TRUE}, only files
specified in this argument are rendered, otherwise all R Markdown files
specified by the book are rendered.}

\item{output_dir}{The output directory. If \code{NULL}, a field named
\code{output_dir} in the configuration file \file{_bookdown.yml} will be
used (possibly not specified, either, in which case a directory name
\file{_book} will be used).}

\item{output_format}{output format, see \link[bookdown:render_book]{bookdown::render_book}. Only
\code{"bookdown::gitbook"} and \code{"bookdown::pdf_book"} are currently handled}

\item{clean_cache}{\link{logical} clean Rmarkdown cache files}

\item{...}{Parameters passed to \link{render_report} and \link[bookdown:render_book]{bookdown::render_book}}

\item{reports_dir}{\link{character} path for the reports}

\item{reports}{\link{character} subfolders containing each report.}

\item{publish_dir}{\link{character} rendering output path relatively to the report
folder which is in format \code{"./reports/my_report"}}
}
\value{
\code{NULL}, this function is used for side effect.
}
\description{
Render fairify reports
}
\examples{
# Create a fairify project in a temporary folder
path <- tempfile(pattern = "fairify_")
fairify::create_fairify(path, git = FALSE, open = FALSE)
owd <- setwd(path)

# Create a report
fairify::add_report("my_report")

# Add a chapter
writeLines(
  c(
    "# A new chapter",
    "",
    "With a new paragraph."
  ),
  file.path(path, "reports", "my_report", "01-new_chapter.Rmd")
)

# Render the report in HTML format
render_reports(reports_dir = file.path(path, "reports"))

# Render the report in PDF format
render_reports(reports_dir = file.path(path, "reports"),
               output_format = "bookdown::pdf_book")

# Back to initial working directory
setwd(owd)
}
